@@ -20,8 +20,6 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-/* $Cambridge: exim/src/src/pdkim/pdkim.c,v 1.14 2010/05/29 19:14:06 nm4 Exp $ */
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -420,7 +418,7 @@ char *pdkim_relax_header (char *header, int crlf) {
     p++;
     q++;
   }
-  if (seen_wsp) q--;
+  if ((q>relaxed) && (*(q-1) == ' ')) q--; /* Squash eventual trailing SP */
   *q = '\0';
   if (crlf) strcat(relaxed,"\r\n");
   return relaxed;
